@@ -36,6 +36,7 @@ logger = log.get_logger(level = log.DEBUG)
 @cli.command
 def command(
 	packages					= [ ],
+	ignore						= [ ],
 	pip_path          		 	= [ ],
 	requirements 				= [ ],
 	pipfile            			= [ ],
@@ -151,7 +152,8 @@ def command(
 					partial(
 						get_registry_from_requirements,
 						**{ "sync": no_cache, "jobs": jobs,
-							"only_packages": packages, "file": file_
+							"only_packages": packages, "file": file_,
+							"ignore_packages": ignore
 						}
 					),
 					requirements
@@ -165,7 +167,8 @@ def command(
 						**{ "user": user, "sync": no_cache,
 							"outdated": not all,
 							"build_dependency_tree": format in _DEPENDENCY_FORMATS,
-							"jobs": jobs, "only_packages": packages
+							"jobs": jobs, "only_packages": packages,
+							"ignore_packages": ignore,
 						}
 					),
 					pip_path
@@ -174,29 +177,13 @@ def command(
 
 		logger.info("Updating registries: %s..." % registries)
 
-		# TODO: Tweaks within parallel.no_daemon_pool to run serially.
-		if yes:
-			with parallel.no_daemon_pool(processes = jobs) as pool:
-				pool.imap_unordered(
-					partial(
-						update_registry,
-						**{ "yes": yes, "user": user, "check": check,
-							"latest": latest, "interactive": interactive,
-							"verbose": verbose, "format_": format, "all": all,
-							"filter": packages, "file": file_,
-							"raise_err": not ignore_error,
-							"upgrade_type": upgrade_type
-						}
-					),
-					registries
-				)
-		else:
-			for registry in registries:
-				update_registry(registry, yes = yes, user = user, check = check,
-					latest = latest, interactive = interactive, verbose = verbose,
-					format_ = format, all = all, file = file_, raise_err = not ignore_error,
-					upgrade_type = upgrade_type
-				)
+		for registry in registries:
+			update_registry(registry, yes = yes, user = user, check = check,
+				latest = latest, interactive = interactive, verbose = verbose,
+				format_ = format, all = all, filter_ = packages,
+				file = file_, raise_err = not ignore_error,
+				upgrade_type = upgrade_type
+			)
 
 		if pipfile:
 			logger.info("Updating Pipfiles: %s..." % pipfile)
